# pySlite

[![PyPI package](https://img.shields.io/badge/pip%20install-pyslite-brightgreen)](https://pypi.org/project/pyslite/)
[![version number](https://img.shields.io/pypi/v/pyslite?color=green&label=version)](https://pypi.org/project/pyslite/)
[![Actions Status](https://github.com/oddaspa/pyslite/workflows/Build%20status/badge.svg)](https://github.com/oddaspa/pyslite/actions)
[![PyPI downloads](https://img.shields.io/pypi/dm/pyslite.svg)](https://pypistats.org/packages/pyslite)
[![License](https://img.shields.io/github/license/oddaspa/pyslite)](https://github.com/oddaspa/pyslite/blob/main/LICENSE.txt)

Unofficial Python SDK for Slite API.

## Installation

```sh
$ pip install pyslite
```
